@@ -13,4 +13,4 @@ def main() -> None:
 # Make the script executable.
 
 if __name__ == "__main__":
-    raise SystemExit(main())
+    main()
