@@ -67,14 +67,14 @@ def main(argv: list[str] | None = None) -> int:
 
     # config
     # if the (first) config file doesn't exist, copy a sample config
-    if not os.path.exists(args.config_path[0]):
+    if not os.path.exists(args.config_path):
         template_path = str(
             importlib.resources.files("edupsyadmin.data") / "sampleconfig.yml"
         )
-        shutil.copy(template_path, args.config_path[0])
+        shutil.copy(template_path, args.config_path)
         logger.info(
             "Could not find the specified config file. "
-            f"Created a sample config at {args.config_path[0]}. "
+            f"Created a sample config at {args.config_path}. "
             "Fill it with your values."
         )
     config.load(args.config_path)
@@ -127,7 +127,7 @@ def _args(argv: list[str] | None) -> argparse.Namespace:
     parser = ArgumentParser()
     # append allows multiple instances of the same object
     # args.config_path will therefore be a list!
-    parser.add_argument("-c", "--config_path", action="append", help=argparse.SUPPRESS)
+    parser.add_argument("-c", "--config_path", help=argparse.SUPPRESS)
     parser.add_argument(
         "-v",
         "--version",
@@ -171,7 +171,7 @@ def _args(argv: list[str] | None) -> argparse.Namespace:
     if not args.config_path:
         # Don't specify this as an argument default or else it will always be
         # included in the list.
-        args.config_path = [DEFAULT_CONFIG_PATH]
+        args.config_path = DEFAULT_CONFIG_PATH
     if not args.salt_path:
         args.salt_path = DEFAULT_SALT_PATH
     return args
@@ -218,10 +218,7 @@ def _edit_config(
         config_path: str | os.PathLike[str],
     ) -> None:
         config_editor_app = lazy_import("edupsyadmin.tui.editconfig").ConfigEditorApp
-        if isinstance(config_path, str):
-            config_editor_app(config_path).run()
-        else:
-            config_editor_app(config_path[0]).run()
+        config_editor_app(config_path).run()
 
     parser = subparsers.add_parser(
         "edit_config",
@@ -250,6 +247,7 @@ def _new_client(
         school: str | None,
         name: str | None,
         keepfile: bool | None,
+        import_config: str | None,
     ) -> None:
         new_client = lazy_import("edupsyadmin.api.managers").new_client
         new_client(
@@ -261,6 +259,7 @@ def _new_client(
             school=school,
             name=name,
             keepfile=keepfile,
+            import_config=import_config,
         )
 
     parser = subparsers.add_parser(
@@ -292,6 +291,13 @@ def _new_client(
             "school from the config will be used."
         ),
     )
+    parser.add_argument(
+        "--import-config",
+        help=(
+            "Only relevant if --csv is set. The name of the csv import configuration "
+            "from the config file to use."
+        ),
+    )
     parser.add_argument(
         "--keepfile",
         action="store_true",
@@ -397,10 +403,11 @@ def _get_clients(
         nta_nos: bool,
         client_id: int,
         out: str | os.PathLike[str],
+        tui: bool,
     ) -> None:
         get_clients = lazy_import("edupsyadmin.api.managers").get_clients
         get_clients(
-            app_username, app_uid, database_url, salt_path, nta_nos, client_id, out
+            app_username, app_uid, database_url, salt_path, nta_nos, client_id, out, tui
         )
 
     parser = subparsers.add_parser(
@@ -419,6 +426,11 @@ def _get_clients(
     parser.add_argument(
         "--client_id", type=int, help="id for a single client to display"
     )
+    parser.add_argument(
+        "--tui",
+        action="store_true",
+        help="show the results ina a tui instead of plain text",
+    )
 
 
 def _create_documentation(
@@ -435,9 +447,9 @@ def _create_documentation(
         app_uid: str,
         database_url: str,
         salt_path: str | os.PathLike[str],
-        client_id: int,
+        client_id: list[int],
         form_set: str,
-        form_paths: list[str],
+        form_paths: list[str] | None,
     ) -> None:
         create_documentation = lazy_import(
             "edupsyadmin.api.managers"
@@ -456,21 +468,24 @@ def _create_documentation(
         "create_documentation",
         parents=[common],
         help="Fill a pdf form or a text file with a liquid template",
-        description="Fill a pdf form or a text file with a liquid template",
+        description=(
+            "Fill a pdf form or a text file with a liquid template. "
+            "Either --form_set or --form_paths must be provided."
+        ),
         usage=(
-            "edupsyadmin create_documentation [-h] client_id "
-            "[--form_set FORM_SET] [form_paths ...]"
+            "edupsyadmin create_documentation [-h] client_id [client_id ...] "
+            "[--form_set FORM_SET] [--form_paths FORM_PATH ...]"
         ),
     )
     parser.set_defaults(command=command_create_documentation)
-    parser.add_argument("client_id", type=int)
+    parser.add_argument("client_id", type=int, nargs="+")
     parser.add_argument(
         "--form_set",
         type=str,
         default=None,
         help="name of a set of file paths defined in the config file",
     )
-    parser.add_argument("form_paths", nargs="*", help="form file paths")
+    parser.add_argument("--form_paths", nargs="*", help="form file paths")
 
 
 def _mk_report(
@@ -552,10 +567,8 @@ def _taetigkeitsbericht(
         database_url: str,
         salt_path: str | os.PathLike[str],
         wstd_psy: float,
-        nstudents: int,
         out_basename: str | os.PathLike[str],
         wstd_total: float,
-        min_per_ses: int,
         name: str,
     ) -> None:
         taetigkeitsbericht = lazy_import(
@@ -567,10 +580,8 @@ def _taetigkeitsbericht(
             database_url=database_url,
             salt_path=salt_path,
             wstd_psy=wstd_psy,
-            n_students=nstudents,
             out_basename=out_basename,
             wstd_total=wstd_total,
-            min_per_ses=min_per_ses,
             name=name,
         )
 
@@ -583,14 +594,6 @@ def _taetigkeitsbericht(
     parser.add_argument(
         "wstd_psy", type=int, help="Anrechnungsstunden in Wochenstunden"
     )
-    parser.add_argument(
-        "nstudents",
-        nargs="+",
-        help=(
-            "list of strings with item containing the name of the school "
-            "and the number of students at that school, e.g. Schulname625"
-        ),
-    )
     parser.add_argument(
         "--out_basename",
         type=str,
@@ -603,16 +606,6 @@ def _taetigkeitsbericht(
         default=23,
         help="total Wochstunden (depends on your school); default is 23",
     )
-    parser.add_argument(
-        "--min_per_ses",
-        type=int,
-        default=45,
-        help=(
-            "duration of one session in minutes; "
-            "used to estimate the number of sessions from `h_sessions`; "
-            "default is 45"
-        ),
-    )
     parser.add_argument(
         "--name",
         type=str,
